# Rebuilding options:
#	--without imlib      = disable imlib support
#	--without xft        = disable xfreetype support
#	--without antialiasing = disable antialiasing
#	--without gradients  = disable gradients
#	--without guievents  = disable guievents
#	--with menus_gnome1  = enable gnome1 menus
#	--with menus_gnome2  = enable gnome2 menus
#   --without xinerama   = disable xinerama support

# %%define alphatag pre2

Name:          icewm
Summary:       Fast and small X11 window manager
Version:       1.2.33
Release:       1.n0i.57%{?alphatag:.%{alphatag}}%{?dist}

Group:         User Interface/Desktops
License:       LGPLv2+
URL:           http://www.icewm.org/

Source0:       http://download.sourceforge.net/%{name}/%{name}-%{version}%{?alphatag:%{alphatag}}.tar.gz
Source1:       http://lostclus.linux.kiev.ua/scripts/icewm-xdg-menu

Source93:      icewm-AltBlue.tar.bz2
Source94:      icewm-AltBlue-BlueCurve.tar.bz2

Patch20:       icewm-1.3.32-quickswitch_raise.patch
#Patch21:       icewm-1.2.24-configure-xft.patch

BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Conflicts:     %{name}-gnome, %{name}-lite, %{name}-default, %{name}-common

BuildRequires: libXt-devel libX11-devel libXrandr-devel xorg-x11-proto-devel
BuildRequires: gettext
%{!?_without_xinerama:BuildRequires: libXinerama-devel}
%{!?_without_xft:BuildRequires: freetype-devel pkgconfig libXft-devel}
%{!?_without_imlib:BuildRequires: imlib-devel libpng-devel}
%{?_with_menus_gnome2:BuildRequires: gnome-desktop-devel pkgconfig}

%description
A lightweight window manager for the X Window System. Optimized for "feel"
and speed, not looks. Features multiple workspaces, opaque move/resize, task
bar, window list, clock, mailbox, CPU, Network, APM status.

This is an experimental packaged version of IceWM. It contains  all the
necessary features build in and some additional experimental features,
including enhanced move/size effects, antialiasing, grandients and shaped
window decorations. Nevertheless, there are options for custom builds
(Check RPM spec).

%package themes
Summary:	Themes collection for IceWM
Group:		User Interface/Desktops
Requires:	%{name}

%description themes
Themes collection for IceWM.

%package xdgmenu
Summary:  XDG menu generator for IceWM
Group:    User Interface/Desktops
Requires: pyxdg
Requires: icewm

%description xdgmenu
This package provides a tool for generating XDG menus for IceWM.

%prep
%setup -q -n %{name}-%{version}%{?alphatag:%{alphatag}}
%patch20 -p1
iconv -f iso-8859-1 -t utf-8 -o CHANGES.enc CHANGES && %{__mv} -f CHANGES.enc CHANGES


%build
# ./autogen.sh
%configure \
	--with-docdir=%{_docdir} \
	%{?_without_imlib:--without-imlib} \
    %{?_without_xft:--disable-xfreetype} \
	%{!?_without_antialiasing:--enable-antialiasing} \
	%{!?_without_gradients:--enable-gradients} \
	%{!?_without_guievents:--enable-guievents} \
    %{?_with_menus_gnome1:--enable-menus-gnome1} \
    %{?_with_menus_gnome2:--enable-menus-gnome2} \

%{__make} %{?_smp_mflags}
%{__make} -C doc


%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR=%{buildroot}

### proper locale dir for "English"
%{__mv} %{buildroot}%{_datadir}/locale/en %{buildroot}%{_datadir}/locale/en_US

%find_lang %{name}

### install "preferences" generator
%{__install} -m0755 src/genpref %{buildroot}%{_bindir}/icewm-genpref

### install XDG menu generator
%{__install} -m0755 %{SOURCE1} %{buildroot}%{_bindir}/

### install our custom themes
%{__tar} xjf %{SOURCE93} -C %{buildroot}%{_datadir}/%{name}/themes/
%{__tar} xjf %{SOURCE94} -C %{buildroot}%{_datadir}/%{name}/themes/

### FreeDesktop entry
%{__install} -d -m0755 %{buildroot}%{_datadir}/xsessions
%{__cat} << 'EOF' > %{buildroot}%{_datadir}/xsessions/icewm.desktop
[Desktop Entry]
Encoding=UTF-8
Name=IceWM
Comment=Simple and fast window manger
Exec=icewm-session
Terminal=False
TryExec=icewm

[Window Manager]
SessionManaged=true
EOF

### IceWM startup file
%{__cat} << 'EOF' > %{buildroot}%{_datadir}/%{name}/startup
#!/bin/sh

# create private IceWM configuration folder if it doesn't already exist
[ -d ~/.icewm ] || mkdir ~/.icewm

# generate default preference file if not already there
[ -f ~/.icewm/preferences ] || icewm-genprefs > ~/.icewm/preferences

# Run "session restart" script if available
[ -x ~/.icewm/restart ] && source ~/.icewm/restart

# start Gnome/KDE "support" tools is possible
for prog in \
	/usr/libexec/{gnome-settings-daemon,notification-daemon} \
	/usr/bin/{dcopserver_shutdown,dcopserver}
do
	[ -x $prog ] && $prog &
done

# create a precached XDG menu if possible
gconftool=/usr/bin/gconftool-2
xdgmenu=/usr/bin/icewm-xdg-menu
if [ -x $gconftool ] ; then
	icon_theme=$($gconftool -g /desktop/gnome/interface/icon_theme 2>/dev/null)
fi
if [ -x $xdgmenu ] ; then
	shopt -u -o noclobber # allow files overwriting with '>'
	$xdgmenu --entire-menu --with-theme-paths --icon-size 16 \
		--theme ${icon_theme:-Bluecurve} > ~/.icewm/programs.autogen
	# plug this file into user's private "menu" file
	[ -f ~/.icewm/menu ] || touch ~/.icewm/menu
	grep -qwE 'icewm-xdg-menu|programs.autogen' ~/.icewm/menu || \
		echo 'menufile Programs folder programs.autogen' >> ~/.icewm/menu
fi
unset gconftool xdgmenu icon_theme
EOF
%{__chmod} +x %{buildroot}%{_datadir}/%{name}/startup


%clean
%{__rm} -rf %{buildroot}


%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS BUGS CHANGES COPYING PLATFORMS README* TODO VERSION
%doc doc/*.html doc/*.sgml icewm.lsm
%{_bindir}/*
%exclude %{_bindir}/icewm-xdg-menu
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/keys
%{_datadir}/%{name}/ledclock
%{_datadir}/%{name}/mailbox
%{_datadir}/%{name}/menu
%{_datadir}/%{name}/preferences
%{_datadir}/%{name}/startup
%{_datadir}/%{name}/taskbar
%dir %{_datadir}/%{name}/themes
%{_datadir}/%{name}/toolbar
%{_datadir}/%{name}/winoptions
%{_datadir}/xsessions/icewm.desktop


%files themes
%defattr(-,root,root)
%{_datadir}/%{name}/themes/*


%files xdgmenu
%defattr(-,root,root)
%{_bindir}/icewm-xdg-menu


%changelog
* Sun Nov 04 2007 Marius FERARU <altblue@n0i.net> - 1.2.33-1.n0i.57
- version 1.2.33
- updated .desktop file (Fedora)
- renamed "icewm_genpref" to "icewm-genpref"
- added icewm-xdg-menu
- baked a (not so) sample "startup" file
- fixed CHANGES encoding
- dropped icewm_min_all.sh (native ShowDesktop got good enough)

* Sun Oct 14 2007 Marius FERARU <altblue@n0i.net> - 1.2.32-16.n0i.56
- updated "quickswitch raise" patch
- changed License tag (Fedora friendly)

* Tue Aug 07 2007 Marius FERARU <altblue@n0i.net> - 1.2.32-15.n0i.55
- version 1.2.32

* Tue Jul 31 2007 Marius FERARU <altblue@n0i.net> - 1.2.31-14.n0i.54
- version 1.2.31

* Wed Jan 24 2007 Marius FERARU <altblue@n0i.net> - 1.2.30-1.n0i.53
- version 1.2.30

* Mon Sep 11 2006 Marius FERARU <altblue@n0i.net> - 1.2.28-1.n0i.52
- version 1.2.28

* Thu Sep 07 2006 Marius FERARU <altblue@n0i.net> - 1.2.28-0.n0i.51.pre2
- version 1.2.28pre2

* Tue Aug 29 2006 Marius FERARU <altblue@n0i.net> - 1.2.28-0.n0i.50.pre1
- version 1.2.28pre1
- more BR (FC5 based)
- one more option: --without xinerama

* Mon Aug 21 2006 Marius FERARU <altblue@n0i.net> - 1.2.27-1.n0i.49
- version 1.2.27

* Mon Apr 17 2006 Marius FERARU <altblue@n0i.net> - 1.2.26-1.n0i.48
- version 1.2.26

* Fri Feb 03 2006 Marius FERARU <altblue@n0i.net> - 1.2.25-1.n0i.47
- version 1.2.25

* Thu Feb 02 2006 Marius FERARU <altblue@n0i.net> - 1.2.25-0.n0i.46.pre1
- version 1.2.25pre1
- dropped previous configure-xft patch (applied upstream)

* Mon Jan 23 2006 Marius FERARU <altblue@n0i.net> - 1.2.24-1.n0i.45
- baked a patch to properly configure Xft support
  on modular X.org installations (libXft)
- dropped more configuration options (count on the "implied" features)

* Mon Jan 23 2006 Marius FERARU <altblue@n0i.net> - 1.2.24-1.n0i.44
- version 1.2.24

* Fri Dec 09 2005 Marius FERARU <altblue@n0i.net> - 1.2.24-0.n0i.43.pre1
- version 1.2.24pre1

* Mon Aug 15 2005 Marius FERARU <altblue@n0i.net> - 1.2.23-3.n0i.42
- version 1.2.23

* Mon Aug 01 2005 Marius FERARU <altblue@n0i.net> - 1.2.23-0.n0i.41.pre1
- version 1.2.23pre1
- dropped previous patch (updated upstream)

* Mon Jul 25 2005 Marius FERARU <altblue@n0i.net> - 1.2.22-2.n0i.40
- baked a patch to allow modifications to KeySysCollapseTaskBar
  (and some more cleanup bindkeys cleanup)

* Mon Jul 18 2005 Marius FERARU <altblue@n0i.net> - 1.2.22-1.n0i.39
- version 1.2.22

* Thu Jul 14 2005 Marius FERARU <altblue@n0i.net> - 1.2.22-0.n0i.38.pre2
- version 1.2.22pre2

* Fri Jun 17 2005 Marius FERARU <altblue@n0i.net> - 1.2.21-1.n0i.37
- version 1.2.21

* Tue Feb 01 2005 Marius FERARU <altblue@n0i.net> - 1.2.10-1.n0i.36
- updated my themes (finally :))
- dropped switchdesk file (included upstream)
- dropped GDM Session file
- moved desktop file into %{_datadir}/xsessions/

* Wed Jan 12 2005 Marius FERARU <altblue@n0i.net> - 1.2.20-1.n0i.35
- version 1.2.20

* Tue Jan 04 2005 Marius FERARU <altblue@n0i.net> - 1.2.19-1.n0i.34
- version 1.2.19

* Fri Dec 24 2004 Marius FERARU <altblue@n0i.net> - 1.2.18-1.n0i.33
- version 1.2.18
- disabled CVS patch

* Thu Dec 02 2004 Marius FERARU <altblue@n0i.net> - 1.2.17-2.n0i.32
- integrated more patches from the current CVS revision

* Wed Nov 24 2004 Marius FERARU <altblue@n0i.net> - 1.2.17-1.n0i.31
- automatic rebuild

* Mon Nov 15 2004 Marius FERARU <altblue@n0i.net> - 1.2.17-1.n0i.30
- version 1.2.17

* Tue Aug 17 2004 Marius FERARU <altblue@n0i.net> - 1.2.16-1.n0i.29
- version 1.2.16
- disabled 2 patches: icewm-showdesktop.patch icewm-1.2.14pre9-wheel.patch

* Thu Jul 22 2004 Marius FERARU <altblue@n0i.net> - 1.2.15-0.n0i.28.pre2
- version 1.2.15pre2

* Thu Jul 08 2004 Marius FERARU <altblue@n0i.net> - 1.2.15-0.n0i.27.pre1
- version 1.2.15pre1

* Sun May 30 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-1.n0i.26
- version 1.2.14
- added my "BlueCurve-like" theme

* Tue May 04 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.25.pre15
- version 1.2.14pre15

* Fri Apr 30 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.24.pre14
- added some patches not yet in the distro:
	- raise on quickselect
	- show desktop keysym
	- mouse wheel changes workspace

* Sun Apr 25 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.23.pre14
- try stripping stuff

* Sun Apr 25 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.22.pre14
- icewm 1.2.14pre14
- dropped icewm_max_horiz.sh as now we have KeyWinMaximizeHoriz and updated
my theme configuration files as appropriate
- added (a backward compatible?) /etc/X11/gdm/Sessions/IceWM file
- split themes into a separate package (bandwidth consumer) :)

* Tue Jan 20 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.21.pre9
- icewm 1.2.14pre9

* Thu Jan 15 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.20.pre8
- icewm 1.2.14pre8

* Mon Jan 05 2004 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.19.pre7
- icewm 1.2.14pre7

* Wed Dec 31 2003 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.18.pre6
- moved to pre6
- dropped icewm-super-old-is-better patch

* Mon Dec 29 2003 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.17.pre5
- revert "Super keys" fix (bug 837302) as it's crippled

* Sun Dec 28 2003 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.16.pre5
- icewm 1.2.14pre5
- added more conditional packaging options

* Tue Dec 09 2003 Marius FERARU <altblue@n0i.net> - 1.2.14-0.n0i.15.1.pre1
- icewm 1.2.14pre1
- added switchdesk file
- added XSession file

* Mon Nov 03 2003 Marius FERARU <altblue@n0i.net> - 1.2.13-0.n0i.14
- spec updates following Fedora guidelines

* Sat Sep 27 2003 Marius FERARU <altblue@n0i.net> - 1.2.13-0.n0i.13
- icewm version 1.2.13

* Sun Sep 21 2003 Marius FERARU <altblue@n0i.net> - 1.2.13-0.n0i.12.pre3
- icewm version 1.2.13pre3

* Thu Sep 11 2003 Marius FERARU <altblue@n0i.net> - 1.2.13-0.n0i.11.pre2
- icewm version 1.2.13pre2

* Tue Jul 29 2003 Marius FERARU <altblue@n0i.net> - 1.2.10-0.n0i.10.pre8
- icewm version 1.2.10pre8
- configuration options updates
- added some conditionals
- added genpref utility to package

* Tue Apr 08 2003 Marius FERARU <altblue@n0i.net> - 1.2.7-2.n0i.9
- rebuild for RHL9

* Fri Mar 14 2003 Marius FERARU <altblue@n0i.net> - 1.2.7-1.n0i.8
- version 1.2.7
- enabled freetype, antialiasing, movesize-fx, gradients

* Fri Mar 14 2003 Marius FERARU <altblue@n0i.net> - 1.2.7-0.n0i.7
- version 1.2.7

* Tue Jan 28 2003 Marius FERARU <altblue@n0i.net> - 1.2.6-1.n0i.6
- version 1.2.6

* Thu Jan 02 2003 Marius FERARU <altblue@n0i.net> - 1.2.3-1.n0i.5
- version 1.2.3
- removed build patch
- removed conditional gnome-menu parameter
- merged with Marko's latest tweaks to his spec

* Wed Nov 20 2002 Marius FERARU <altblue@n0i.net> - 1.2.3-1.n0i.4.pre1
- version 1.2.3pre1
- removed gnome2 patch, doesn't work as expected
- added a custom build patch to work with RH8.x stuff

* Wed Sep 18 2002 Marius FERARU <altblue@n0i.net> - 1.2.2-1.n0i.3
- version 1.2.2
- more rpm 4.1 spec tweaks
- gnome 2.x basic compatibility patch

* Fri Sep 06 2002 Marius FERARU <altblue@n0i.net> - 1.2.1-1.n0i.2
- I rewritten the spec file for my very custom needs: full featured icewm
- icewm version 1.2.1

* Sat Dec 01 2001 Marius FERARU <altblue@n0i.net> - 1.2.0-1.n0i.1
- recursive rpm building sucks... but I don't figure yet an elegant way
to avoid it (icewm-common package) but at least I tweaked the code to
make it buildable with rpm version >= 4.0.3
- baked a RedHat package starting from Mathias Hasselmann's SUSE spec
